.. currentmodule:: sardana.sardanadefs

:mod:`~sardana.sardanadefs`
=============================

.. automodule:: sardana.sardanadefs

.. rubric:: Constants

.. autodata:: sardana.sardanadefs.EpsilonError

.. autodata:: sardana.sardanadefs.InvalidId

.. autodata:: sardana.sardanadefs.InvalidAxis

.. autodata:: sardana.sardanadefs.TYPE_ELEMENTS

.. autodata:: sardana.sardanadefs.TYPE_GROUP_ELEMENTS

.. autodata:: sardana.sardanadefs.TYPE_MOVEABLE_ELEMENTS

.. autodata:: sardana.sardanadefs.TYPE_PHYSICAL_ELEMENTS

.. autodata:: sardana.sardanadefs.TYPE_ACQUIRABLE_ELEMENTS

.. autodata:: sardana.sardanadefs.TYPE_PSEUDO_ELEMENTS

.. autodata:: sardana.sardanadefs.SardanaServer

.. rubric:: Enumerations

.. autodata:: sardana.sardanadefs.ServerRunMode

.. autodata:: sardana.sardanadefs.State

.. autodata:: sardana.sardanadefs.DataType

.. autodata:: sardana.sardanadefs.DataFormat

.. autodata:: sardana.sardanadefs.DataAccess

.. autodata:: sardana.sardanadefs.ElementType

.. autodata:: sardana.sardanadefs.Interface

.. autodata:: sardana.sardanadefs.Interfaces

.. autodata:: sardana.sardanadefs.InterfacesExpanded

.. autodata:: sardana.sardanadefs.INTERFACES

.. autodata:: sardana.sardanadefs.INTERFACES_EXPANDED

.. rubric:: Functions

.. autofunction:: sardana.sardanadefs.from_dtype_str

.. autofunction:: sardana.sardanadefs.from_access_str

.. autofunction:: sardana.sardanadefs.to_dtype_dformat

.. autofunction:: sardana.sardanadefs.to_daccess

